@@ -41,15 +41,20 @@
 
 /* **** Exit game */
 void Callback_Exit(GtkWidget* menuitem)  {
+	(void)menuitem;
 
 	intro_free_pngs();
 	game_free_pngs();
+#ifdef WIN32
+	WSACleanup();
+#endif
 	gtk_exit(0);
 }
 
 
 /* **** Show Configuration Panel */
 void Callback_ShowConfiguration(GtkWidget* menuitem)  {
+	(void)menuitem;
 
 	interface_create_config_panel();
 }
@@ -57,6 +62,7 @@ void Callback_ShowConfiguration(GtkWidget* menuitem)  {
 
 /* **** Show all monopd servers */
 void Callback_ShowMetaServer(GtkWidget* button)  {
+	(void)button;
 
 	create_connection_metaserver(CONNECT_TYPE_META_GETLIST);
 }
@@ -64,6 +70,7 @@ void Callback_ShowMetaServer(GtkWidget* button)  {
 
 /* **** Get games from all monopd server */
 void Callback_RefreshGameMetaServer(GtkWidget* button)  {
+	(void)button;
 
 	create_connection_metaserver(CONNECT_TYPE_META_GETGAME);
 }
@@ -117,6 +124,8 @@ void Callback_GetGame_Select(GtkWidget* clist, gint row)  {
 
 /* get games: event "row_unselect" */
 void Callback_GetGame_Unselect(GtkWidget* clist, gint row)  {
+	(void)clist;
+	(void)row;
 
 	if(global->selected_host)  g_free(global->selected_host);
 	if(global->selected_gametype)  g_free(global->selected_gametype);
@@ -128,7 +137,8 @@ void Callback_GetGame_Unselect(GtkWidget* clist, gint row)  {
 
 
 /* **** Join/create a game */
-void Callback_ConnectButton(GtkWidget* clist)  {
+void Callback_ConnectButton(GtkWidget* button)  {
+	(void)button;
 
 	gint32 connectid;
 	gchar *text;
@@ -183,6 +193,7 @@ void Callback_ConnectButton(GtkWidget* clist)  {
 
 /* **** Start the game :) */
 void Callback_StartButton(GtkWidget* button)  {
+	(void)button;
 
 	client_send(game->connectid, ".gs\n", 4);
 }
@@ -190,6 +201,7 @@ void Callback_StartButton(GtkWidget* button)  {
 
 /* **** Enter in the real program */
 void Callback_EnterButton(GtkWidget* button)  {
+	(void)button;
 
 	interface_create_getgamespage();
 }
@@ -197,6 +209,7 @@ void Callback_EnterButton(GtkWidget* button)  {
 
 /* *** send data to server */
 void Callback_SendButton(GtkWidget* Button, GtkWidget *entry) {
+	(void)Button;
 
 	gchar *tmp, *tmp2;
 
@@ -220,6 +233,7 @@ void Callback_SendButton(GtkWidget* Button, GtkWidget *entry) {
 
 /* *** Un/Float Server Message Box*/
 void CallBack_toggle_float_message(GtkWidget* widget) {
+	(void)widget;
 
 	if(global->phase != PHASE_GAMEPLAY) return;
 
@@ -230,6 +244,7 @@ void CallBack_toggle_float_message(GtkWidget* widget) {
 
 /* *** Un/Float Chat Box*/
 void CallBack_toggle_float_chat(GtkWidget* widget) {
+	(void)widget;
 
 	if(global->phase != PHASE_GAMEPLAY) return;
 
@@ -264,18 +279,19 @@ void CallBack_delete_window_chat(GtkWidget* widget) {
 
 /* *** "destroy" signal window message */
 void CallBack_destroy_window_message(GtkWidget* widget) {
-
+	(void)widget;
 }
 
 
 /* *** "destroy" signal window chat */
 void CallBack_destroy_window_chat(GtkWidget* widget) {
-
+	(void)widget;
 }
 
 
 /* *** save and apply the config */
 void CallBack_ok_button_configwindow(GtkWidget* widget)  {
+	(void)widget;
 
 	gchar *filename, *errormsg;
 	FILE *file;
@@ -332,6 +348,7 @@ void CallBack_ok_button_configwindow(GtkWidget* widget)  {
 
 /* *** reallow show config panel */
 void CallBack_configwindow_destroyed(GtkWidget* widget)  {
+	(void)widget;
 
 	global->ConfigWin = 0;
 }
@@ -350,6 +367,7 @@ void CallBack_button_command_pressed(GtkWidget* button) {
 
 /* *** button command pressed */
 void Callback_AuctionButton_Absolute(GtkWidget* button, GtkWidget* entry)  {
+	(void)button;
 
 	gchar *tosend, *auction, *money;
 
@@ -389,23 +407,28 @@ void Callback_AuctionButton_Relative(GtkWidget* button)  {
 void Callback_ClicOnEstate(GtkWidget* widget, GdkEventButton *event)  {
 
 	guint8 id = atoi( gtk_object_get_data(GTK_OBJECT(widget), "estateid") );
-	gchar *text;
+	gchar *text = NULL;
 
 	if(event->button == 1)  { /* left clic -> build house */
-
+#ifdef WIN32
+		if (event->state & GDK_CONTROL_MASK) /* left+ctrl -> mortgage */
+			text = g_strdup_printf(".em%d\n", id);
+		else
+#endif
 		text = g_strdup_printf(".hb%d\n", id);
-		client_send(game->connectid, text, strlen(text) );
-		g_free(text);
 	}
+
 	if(event->button == 3)  { /* right clic -> sell house */
-
 		text = g_strdup_printf(".hs%d\n", id);
-		client_send(game->connectid, text, strlen(text) );
-		free(text);
 	}
-	if(event->button == 2)  { /* middle clic -> toggle_mortgage */
 
+#ifndef WIN32
+	if(event->button == 2)  { /* middle clic -> toggle_mortgage */
 		text = g_strdup_printf(".em%d\n", id);
+	}
+#endif
+
+	if (text) {
 		client_send(game->connectid, text, strlen(text) );
 		g_free(text);
 	}
@@ -442,7 +465,7 @@ void Callback_ClicOnPlayer(GtkWidget* widget, GdkEvent *event)  {
 
 	GtkWidget *menu = gtk_object_get_data(GTK_OBJECT(widget), "menu");
 
-	if (event->type == GDK_BUTTON_PRESS)  { 
+	if (event->type == GDK_BUTTON_PRESS)  {
 
 		GdkEventButton *button_event = (GdkEventButton *)event;
 
@@ -515,6 +538,7 @@ void Callback_toggle_boolean_gameoption(GtkWidget* widget)  {
 
 /* *** callback for the entry menu change nickname */
 void CallBack_menu_change_nickname(GtkWidget* widget)  {
+	(void)widget;
 
 	if(global->phase >= PHASE_GAMECREATE)
 		interface_create_nicknamewin();
@@ -522,17 +546,17 @@ void CallBack_menu_change_nickname(GtkWidget* widget)  {
 
 
 /* *** callback for the ok button of window change nickname */
-void CallBack_response_changenick_window(GtkWidget* widget, gint response, 
-		GtkWidget *Win)  
-{
+void CallBack_response_changenick_window(GtkWidget* widget, gint response, GtkWidget *Win) {
+	(void)widget;
+
 	if(response == GTK_RESPONSE_OK)
 	{
 		GtkWidget *Entry = gtk_object_get_data(GTK_OBJECT(Win), "nickname");
 		gchar *nickname, *sendstr;
 
 		nickname = g_strdup( gtk_entry_get_text(GTK_ENTRY( Entry ) )  );
-	
-		if(strcmp(global->player[ get_player_slot_with_playerid(game->my_playerid) ].name, nickname) )  
+
+		if(strcmp(global->player[ get_player_slot_with_playerid(game->my_playerid) ].name, nickname) )
 		{
 			sendstr = g_strdup_printf(".n%s\n", nickname);
 			client_send(game->connectid, sendstr, strlen(sendstr) );
@@ -548,6 +572,7 @@ void CallBack_response_changenick_window(GtkWidget* widget, gint response,
 
 /* *** callback for the entry menu reconnect */
 void CallBack_menu_reconnect(GtkWidget* widget)  {
+	(void)widget;
 
 	gchar *host, *tmp, *cookie, *filename;
 	guint32 port;
@@ -647,7 +672,7 @@ void CallBack_trade_button(GtkWidget *button)  {
 void CallBack_trade_sub_component(GtkWidget *menuitem)  {
 
 	gchar *component = gtk_object_get_data( GTK_OBJECT(menuitem), "component" );
-	guint32 tradeslot = get_trade_slot_with_tradeid( atoi( gtk_object_get_data( GTK_OBJECT(menuitem), "tradeid" )  )  );
+	gint32 tradeslot = get_trade_slot_with_tradeid( atoi( gtk_object_get_data( GTK_OBJECT(menuitem), "tradeid" )  )  );
 
 	if(!component) return;
 	if(tradeslot < 0) return;
@@ -711,6 +736,7 @@ void CallBack_trade_update_component(GtkWidget *button)  {
 
 
 void CallBack_logo_page_destroyed(GtkWidget *widget)  {
+	(void)widget;
 
 	frame_destroy(global->logo_frame);
 	intro_free_pngs();
@@ -719,6 +745,7 @@ void CallBack_logo_page_destroyed(GtkWidget *widget)  {
 
 /* *** callback for the entry menu leave game */
 void CallBack_menu_LeaveGame(GtkWidget* widget)  {
+	(void)widget;
 
 	gchar *sendstr;
 
@@ -737,6 +764,7 @@ void CallBack_menu_LeaveGame(GtkWidget* widget)  {
 
 /* *** callback for the entry menu close all connections */
 void CallBack_menu_CloseAllConnections(GtkWidget* widget)  {
+	(void)widget;
 
 	guint32 i;
 
@@ -752,6 +780,7 @@ void CallBack_menu_CloseAllConnections(GtkWidget* widget)  {
 
 /* *** Show estates tree */
 void CallBack_estates_tree(GtkWidget* widget) {
+	(void)widget;
 
 	if(global->phase != PHASE_GAMEPLAY) return;
 
@@ -761,6 +790,7 @@ void CallBack_estates_tree(GtkWidget* widget) {
 
 /* *** callback for the entry menu declare bankrupcy */
 void CallBack_menu_DeclareBankrupcy(GtkWidget* widget)  {
+	(void)widget;
 
 	gchar *sendstr;
 
@@ -1004,13 +1034,15 @@ void CallBack_EstateTree_SelectRow(GtkCTree *EstateTree,  GtkCTreeNode *Node)  {
 
 
 void CallBack_EstateTree_UnSelectRow(GtkCTree *EstateTree,  GtkCTreeNode *Node)  {
+	(void)EstateTree;
+	(void)Node;
 
-	gchar *data;
+//	gchar *data;
 	GtkWidget *parent, *info, *Alignment, *Label;
-	gint32 id;
+//	gint32 id;
 
-	data = gtk_ctree_node_get_row_data(GTK_CTREE(EstateTree), Node);
-	id = atoi(data);
+//	data = gtk_ctree_node_get_row_data(GTK_CTREE(EstateTree), Node);
+//	id = atoi(data);
 
 	parent = gtk_object_get_data(GTK_OBJECT(game->WinEstateTree), "parent_box");
 	info = gtk_object_get_data(GTK_OBJECT(game->WinEstateTree), "info_box");
@@ -1035,6 +1067,7 @@ void CallBack_EstateTree_UnSelectRow(GtkCTree *EstateTree,  GtkCTreeNode *Node)
 
 
 void CallBack_EstateTree_Destroyed(GtkWidget *widget)  {
+	(void)widget;
 
 	game->WinEstateTree = 0;
 }
@@ -1103,12 +1136,14 @@ void Callback_ProposalList_Unselect(GtkWidget* clist, gint row)  {
 
 
 void CallBack_HelpWin_Destroyed(GtkWidget *widget)  {
+	(void)widget;
 
 	global->HelpWin = 0;
 }
 
 
 void Callback_menu_Themes(GtkWidget *widget)  {
+	(void)widget;
 
 	if(global->ThemeWin)  return;
 
@@ -1119,6 +1154,7 @@ void Callback_menu_Themes(GtkWidget *widget)  {
 
 
 void CallBack_ThemeWin_Delete(GtkWidget *widget)  {
+	(void)widget;
 
 	theme_preview_free();
 	gtk_widget_destroy(global->ThemeWin);
@@ -1126,6 +1162,7 @@ void CallBack_ThemeWin_Delete(GtkWidget *widget)  {
 
 
 void CallBack_ThemeWin_Destroyed(GtkWidget *widget)  {
+	(void)widget;
 
 	global->ThemeWin = 0;
 }
@@ -1158,13 +1195,14 @@ void Callback_ThemeList_Select(GtkWidget* clist, gint row)  {
 
 /* theme list: event "row_unselect" */
 void Callback_ThemeList_Unselect(GtkWidget* clist, gint row)  {
-
-
+	(void)clist;
+	(void)row;
 }
 
 
 /* select/apply a theme */
 void CallBack_Theme_Apply(GtkWidget* button)  {
+	(void)button;
 
 	theme_load( atoi( gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_selected") ) );
 }
