@@ -26,13 +26,21 @@
 #include <unistd.h>
 #include <string.h>
 
+#ifndef WIN32
 #include <netdb.h>
 #include <sys/socket.h>
 #include <arpa/inet.h>
+#include <netinet/in.h>
+
+#define closesocket close
+
+#else
+#include <winsock2.h>
+#endif
+
 #include <sys/time.h>
 #include <sys/types.h>
 #include <time.h>
-#include <netinet/in.h>
 
 #include "config.h"
 #include "xmlparse.h"
@@ -40,6 +48,18 @@
 #include "client.h"
 #include "game.h"
 
+#if !defined(HAVE_INET_ATON) || defined(WIN32)
+#ifndef INADDR_NONE
+#define INADDR_NONE 0xffffffff
+#endif
+
+int inet_aton(const char *cp, struct in_addr *addr) {
+
+	addr->s_addr = inet_addr(cp);
+	return addr->s_addr != INADDR_NONE;
+}
+#endif
+
 
 /* -- connect to server
      >
@@ -57,7 +77,7 @@ gboolean client_connect(gint32 *idconnect, gchar* host, gint32 port)  {
 	gpointer errormsg;
 	gchar *text;
 	gint32 idcon;
-	gint32 sock;
+	socket_t sock;
 
 
 	if( !connect_get_valid_id(&idcon) )  {
@@ -133,7 +153,7 @@ gboolean client_disconnect(gint32 idconnect)  {
 
 	shutdown (connection[idconnect]->socket, 2);
 
-	if(close(connection[idconnect]->socket))  {
+	if(closesocket(connection[idconnect]->socket))  {
 
 		errormsg = g_strdup_printf("[ERROR] Connection \"%d\" : can't close socket", idconnect);
 		text_insert_message(errormsg, strlen(errormsg));
@@ -207,7 +227,8 @@ gboolean client_fonct()  {
 gint32 client_recv(gint32 id)
 {
 	gchar *data, *buffer = 0, *buffer2, *tmp;
-	gint32 len, sock, i;
+	gint32 len, i;
+	socket_t sock;
 
 	if(!connection_is_open[id])  return(FALSE);
 	if(!connection[id]->connected)  return(FALSE);
@@ -217,9 +238,7 @@ gint32 client_recv(gint32 id)
 	/* get data from server */
 	data = g_malloc0(GETDATA_STEP +SECURITY_SIZE);
 	do  {
-
-		len = read(sock, data, GETDATA_STEP);
-
+		len = recv(sock, data, GETDATA_STEP, 0);
 		data[len] = '\0';
 
 		if(len <= 0)  {
@@ -310,7 +329,7 @@ gboolean client_send(gint32 id, gchar *data, gint32 lenght_data)  {
 	if(!connection_is_open[id])  return(TRUE);
 	if(!connection[id]->connected)  return(TRUE);
 
-	t = write(connection[id]->socket, data, lenght_data);
+	t = send(connection[id]->socket, data, lenght_data, 0);
 
 	if(t != lenght_data) {
 
