@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
 
 
 /* ** prototypes for connect/disconnect to server */
-gboolean client_connect(guint16 *idconnect, gchar* host, guint32 port);
-gboolean client_disconnect(guint32 id);
+gboolean client_connect(gint32 *idconnect, gchar* host, gint32 port);
+gboolean client_disconnect(gint32 id);
 gboolean client_fonct();
 gint32   client_recv(gint32 id);
-gboolean client_send(guint32 id, gchar *data, guint32 lenght_data);
+gboolean client_send(gint32 id, gchar *data, gint32 lenght_data);
