@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -31,8 +31,8 @@ void display_clear_text();
 void display_clear_buttons();
 void display_init();
 void display_estate(gint32 estateid);
-void display_title(guchar *text);
-void display_text(guchar *message);
-void display_button(guchar *caption, guchar *command, gboolean enabled);
+void display_title(gchar *text);
+void display_text(gchar *message);
+void display_button(gchar *caption, gchar *command, gboolean enabled);
 
 
