@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,16 +24,16 @@
 /* -- prototypes for eng_frame.c -- */
 
 void eng_create_frame_all();
-void eng_create_frame     (guint16 frame_id);
-void pic_get_zone_update  (guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gint * x2, gint * y2);
-void pic_get_zone_old     (guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gint * x2, gint * y2);
-void pic_get_zone_new     (guint16 frame_id, guint16 pic_id, gint * x1, gint * y1, gint * x2, gint * y2);
+void eng_create_frame     (gint32 frame_id);
+void pic_get_zone_update  (gint32 frame_id, gint32 pic_id, gint * x1, gint * y1, gint * x2, gint * y2);
+void pic_get_zone_old     (gint32 frame_id, gint32 pic_id, gint * x1, gint * y1, gint * x2, gint * y2);
+void pic_get_zone_new     (gint32 frame_id, gint32 pic_id, gint * x1, gint * y1, gint * x2, gint * y2);
 
-void eng_update_bufout    (guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2);
-void eng_set_bg_bufout    (guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2);
+void eng_update_bufout    (gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2);
+void eng_set_bg_bufout    (gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2);
 
-gboolean eng_zone_is_modified(guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2);
-gpointer eng_get_zone     (guint16 frame_id, guint16 x1, guint16 y1, guint16 x2, guint16 y2);
-gpointer eng_get_next_zone(guint16 frame_id, guint16 * x, guint16 * y, guint16 * width, guint16 * height);
+gboolean eng_zone_is_modified(gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2);
+gpointer eng_get_zone     (gint32 frame_id, gint32 x1, gint32 y1, gint32 x2, gint32 y2);
+gpointer eng_get_next_zone(gint32 frame_id, gint32 * x, gint32 * y, gint32 * width, gint32 * height);
 
 /* -- end of prototypes -- */
