@@ -41,6 +41,13 @@
 #include "trade.h"
 #include "engine.h"
 
+#ifdef WIN32
+#include <windows.h>
+#include <io.h>
+#define mkdir(p, m) _mkdir(p)
+#undef PACKAGE_DATA_DIR
+#define PACKAGE_DATA_DIR "./data"
+#endif
 
 /* create home directory (~/.gtkatlantic) *
  * return TRUE if exist/created, return FALSE if cannot be created */
@@ -49,7 +56,23 @@ gboolean create_home_directory()  {
 	gchar *path;
 	struct stat s;
 
+#ifndef WIN32
 	path = g_strconcat( getenv("HOME"), "/", ".", PACKAGE, "/", NULL);
+#else
+	HKEY hKey;
+	TCHAR home[PATH_MAX];
+	DWORD size = PATH_MAX;
+
+	if (RegOpenKeyEx(HKEY_CURRENT_USER,
+		"Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders",
+		0, KEY_READ, &hKey) != ERROR_SUCCESS ||
+		RegQueryValueEx(hKey, "Personal", NULL, NULL, (LPBYTE)home, &size) != ERROR_SUCCESS ||
+		RegCloseKey(hKey) != ERROR_SUCCESS) {
+			path = g_strconcat(PACKAGE, "/", NULL);
+	} else {
+		path = g_strconcat(home, "/", PACKAGE, "/", NULL);
+	}
+#endif /* WIN32 */
 	global->path_home = g_strdup(path);
 	if(stat(path, &s) < 0)  {
 
@@ -351,7 +374,7 @@ gboolean game_get_valid_player_slot(gint32 *playerslot)  {
 
 	for(i = 0; i < MAX_PLAYERS; i++)
 		if(!global->player[i].playerid) {
-	
+
 			*playerslot = i;
 			return TRUE;
 		}
@@ -367,7 +390,7 @@ gint32 get_player_slot_with_playerid(gint32 playerid)  {
 
 	for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
-		if(global->player[i].playerid == playerid) {
+		if((gint32)global->player[i].playerid == playerid) {
 
 			return(i);
 			break;
@@ -569,12 +592,15 @@ void parse_specific_send_message(gchar *message)   {
 
 
 	else if(! strncmp(msg, "date", 4))  {
+		gint32 len;
 
 		gettimeofday(&tv, NULL);
 		t_now = tv.tv_sec;
 
 		tmp = g_strdup_printf("%s", ctime(&t_now) );
-		for(i = 0 ; i < strlen(tmp) ; i++)  {
+		len = strlen(tmp);
+
+		for(i = 0 ; i < len ; i++)  {
 
 			if(tmp[i] == '\n')  {
 				tmp[i] = '\0';
@@ -718,7 +744,7 @@ gint32 get_playerid_by_playername(gchar *name)  {
 
 		if(! global->player[i].playerid)  continue;
 		if(!global->player[i].name) continue;
-		
+
 		if(! strcmp(global->player[i].name, name) )  {
 
 			return( global->player[i].playerid );
@@ -1065,10 +1091,10 @@ void game_delete_player(gint32 id)  {
 	/* delete a player */
 	frame_destroy( global->player[id].playerlist_token_frame );
 	frame_destroy( global->player[id].playerlist_cards_frame );
-	
+
 	if(global->player[id].name) g_free(global->player[id].name);
 	if(global->player[id].host) g_free(global->player[id].host);
 	if(global->player[id].image) g_free(global->player[id].image);
-	
+
 	memset(&global->player[id], 0, sizeof(_player) );
 }
