@@ -25,6 +25,12 @@
 #include <time.h>
 #include <sys/time.h>
 
+#ifndef WIN32
+typedef int socket_t;
+#else
+#include <winsock2.h>
+typedef SOCKET socket_t;
+#endif
 
 /* -- hierarchy
  *
@@ -264,7 +270,7 @@ typedef struct {
 
 	gchar   *host;
 	gint32  port;
-	guint32 socket;
+	socket_t socket;
 	gchar  *server_version;
 
 	gchar *buffer_in;
@@ -489,7 +495,6 @@ typedef struct  {
 	GtkStyle *style_normal;
 	GtkStyle *style_player_normal;
 	GtkStyle *style_player_turn;
-	GtkStyle *style_estate_title;
 
 } _global;
 
@@ -523,3 +528,4 @@ typedef struct  {
 } _config;
 
 _config *config;
+
