@@ -38,6 +38,10 @@
 
 #include "icon.xpm"
 
+#ifdef WIN32
+#undef PACKAGE_DATA_DIR
+#define PACKAGE_DATA_DIR "./data"
+#endif
 
 void interface_create_mainwindow()  {
 
@@ -813,7 +817,7 @@ void interface_create_gameboardpage()  {
 			pic_set_width(frame, pic, data->pngfile_card_width[t]);
 			pic_set_height(frame, pic, data->pngfile_card_height[t]);
 
-			if(game->estate[ data->playerlist_card[j].estateid ].owner  ==  global->player[i].playerid)  {
+			if(game->estate[ data->playerlist_card[j].estateid ].owner  ==  (gint32)global->player[i].playerid)  {
 
 				if(game->estate[ data->playerlist_card[j].estateid ].mortgaged)  {
 
@@ -1052,7 +1056,11 @@ void interface_create_gameboardpage()  {
 	text_insert_message(text, strlen(text));
 	display_text(text);
 	g_free(text);
+#ifndef WIN32
 	text = g_strdup("Mortgage: Press middle button on estate to toggle.");
+#else
+	text = g_strdup("Mortgage: Press ctrl+left button on estate to toggle.");
+#endif
 	text_insert_message(text, strlen(text));
 	display_text(text);
 	g_free(text);
@@ -1483,9 +1491,6 @@ void interface_create_auctionbox()  {
 //	hbox_text = gtk_hbox_new(FALSE, 0);
 //	gtk_box_pack_start(GTK_BOX(vbox), hbox_text, TRUE, TRUE, 0);
 
-	hbox_entry = gtk_hbox_new(FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), hbox_entry, FALSE, TRUE, 0);
-
 	/* text box */
 	scrolledwindow = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrolledwindow),
@@ -1503,6 +1508,10 @@ void interface_create_auctionbox()  {
 	gtk_container_add(GTK_CONTAINER(scrolledwindow), text);
 	gtk_box_pack_start(GTK_BOX(vbox), scrolledwindow, TRUE, TRUE, 0);
 
+	/* commands */
+	hbox_entry = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), hbox_entry, FALSE, TRUE, 0);
+
 	/* send entry */
 	entry = gtk_entry_new();
 	gtk_object_set_data(GTK_OBJECT(game->BoardCenter), "auction_entry", entry);
@@ -1588,7 +1597,7 @@ void interface_create_aboutwin()
 	g_free(text);
 
 	/* web site */
-	Label = gtk_label_new("http://gtkatlantic.sourceforge.net");
+	Label = gtk_label_new("http://gtkatlantic.gradator.net");
 	gtk_box_pack_start(GTK_BOX(VBox), Label, FALSE,	FALSE, 5);
 
 	/* license */
@@ -1631,7 +1640,6 @@ void interface_create_config_panel()  {
 								GtkWidget *Scale;
 		GtkWidget *Button;
 
-	GList *list;
 	gchar *text;
 
 	if(global->ConfigWin)  return;
@@ -1811,23 +1819,19 @@ void interface_create_config_panel()  {
 	Label = gtk_label_new("Display player list at ");
 	gtk_box_pack_start(GTK_BOX(hboxFrame), Label, FALSE, FALSE, 0);
 
-	Combo = gtk_combo_new();
-	gtk_object_set_data(GTK_OBJECT(global->ConfigWin), "config_gameinterface_playerlistposition", GTK_COMBO(Combo)->entry );
+	Combo = gtk_combo_box_entry_new_text();
+	gtk_object_set_data(GTK_OBJECT(global->ConfigWin), "config_gameinterface_playerlistposition", GTK_BIN(Combo)->child);
 	gtk_widget_set_usize(Combo, 60, 0);
-	gtk_editable_set_editable( GTK_EDITABLE(GTK_COMBO(Combo)->entry), FALSE);
+	gtk_editable_set_editable( GTK_EDITABLE(GTK_BIN(Combo)->child), FALSE);
 	gtk_box_pack_start(GTK_BOX(hboxFrame), Combo, FALSE, FALSE, 0);
 
-	list = NULL;
-	list = g_list_append(list, "left");
-	list = g_list_append(list, "right");
-	gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
-	gtk_combo_set_use_arrows_always(GTK_COMBO(Combo), TRUE);
-	g_list_free(list);
+	gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), "left");
+	gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), "right");
 
 	if(config->game_playerlist_position == GAME_PLAYERLIST_POS_LEFT)
-		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(Combo)->entry), "left");
+		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(Combo)->child), "left");
 	else
-		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(Combo)->entry), "right");
+		gtk_entry_set_text(GTK_ENTRY(GTK_BIN(Combo)->child), "right");
 
 
 	hboxFrame = gtk_hbox_new(FALSE, BORDER);
@@ -2142,6 +2146,7 @@ void gameclist_title_showservers()  {
 
 /* generic window with a label into */
 void interface_create_messagewin(gchar *msg)  {
+	(void)msg;
 
 /*	GtkWidget *MessageWin;
 		GtkWidget *VBox;
@@ -2187,6 +2192,7 @@ void interface_create_messagewin(gchar *msg)  {
 
 /* when receive event: redraw an estate */
 void on_board_expose (GtkWidget *widget, GdkEventExpose *event)   {
+	(void)event;
 
 	gchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "estateid");
 
@@ -2195,6 +2201,7 @@ void on_board_expose (GtkWidget *widget, GdkEventExpose *event)   {
 
 /* when receive event: redraw player token */
 void on_playertoken_expose (GtkWidget *widget, GdkEventExpose *event)   {
+	(void)event;
 
 	gchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "player");
 
@@ -2203,6 +2210,7 @@ void on_playertoken_expose (GtkWidget *widget, GdkEventExpose *event)   {
 
 /* when receive event: redraw player cards */
 void on_playercards_expose (GtkWidget *widget, GdkEventExpose *event)   {
+	(void)event;
 
 	gchar *ptr = gtk_object_get_data(GTK_OBJECT(widget), "player");
 
@@ -2212,6 +2220,8 @@ void on_playercards_expose (GtkWidget *widget, GdkEventExpose *event)   {
 
 /* when receive event: redraw logo */
 void on_logo_expose (GtkWidget *widget, GdkEventExpose *event)   {
+	(void)widget;
+	(void)event;
 
 	global->logo_redraw = TRUE;
 }
@@ -2219,6 +2229,8 @@ void on_logo_expose (GtkWidget *widget, GdkEventExpose *event)   {
 
 /* when receive event: redraw theme preview */
 void on_theme_preview_expose (GtkWidget *widget, GdkEventExpose *event)   {
+	(void)widget;
+	(void)event;
 
 	global->theme_redraw = TRUE;
 }
