@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -47,7 +47,7 @@ void interface_create_helpwin();
 void gameclist_title_showgames();
 void gameclist_title_showservers();
 
-void interface_create_messagewin(guchar *msg);
+void interface_create_messagewin(gchar *msg);
 
 void on_board_expose (GtkWidget *widget, GdkEventExpose *event);
 void on_playertoken_expose (GtkWidget *widget, GdkEventExpose *event);
