@@ -37,6 +37,10 @@
 #include "readpng.h"
 #include "parser.h"
 
+#ifdef WIN32
+#undef PACKAGE_DATA_DIR
+#define PACKAGE_DATA_DIR "./data"
+#endif
 
 /* parse a config file */
 gboolean parse_file_config(gchar *filename)  {
@@ -167,7 +171,7 @@ gboolean xmlparse_file_interface()  {
 		return FALSE;
 	}
 
-	cur = cur->xmlChildrenNode; 
+	cur = cur->xmlChildrenNode;
 	do {
 
 		/* ===== PNGFILES ===== */
@@ -654,7 +658,7 @@ gboolean xmlparse_file_interface()  {
 			g_free(tmp);
 
 			tmp = xmlGetProp(cur, (xmlChar*)"alphaunowned");
-			if(! g_strncasecmp((gchar*)tmp, "0x", 2) )  {
+			if(! g_ascii_strncasecmp((gchar*)tmp, "0x", 2) )  {
 
 				sscanf((gchar*)tmp, "0x%2X", &color);
 				data->playerlist_cards_alphaunowned = color;
@@ -663,7 +667,7 @@ gboolean xmlparse_file_interface()  {
 			g_free(tmp);
 
 			tmp = xmlGetProp(cur, (xmlChar*)"alphaowned");
-			if(! g_strncasecmp((gchar*)tmp, "0x", 2) )  {
+			if(! g_ascii_strncasecmp((gchar*)tmp, "0x", 2) )  {
 
 				sscanf((gchar*)tmp, "0x%2X", &color);
 				data->playerlist_cards_alphaowned = color;
@@ -672,7 +676,7 @@ gboolean xmlparse_file_interface()  {
 			g_free(tmp);
 
 			tmp = xmlGetProp(cur, (xmlChar*)"alphamortgage");
-			if(! g_strncasecmp((gchar*)tmp, "0x", 2) )  {
+			if(! g_ascii_strncasecmp((gchar*)tmp, "0x", 2) )  {
 
 				sscanf((gchar*)tmp, "0x%2X", &color);
 				data->playerlist_cards_alphamortgage = color;
@@ -1212,7 +1216,6 @@ void game_free_pngs()  {
 }
 
 
-
 void init_prototype_gtk_style()  {
 
 	GtkWidget *label;
@@ -1242,11 +1245,5 @@ void init_prototype_gtk_style()  {
 	global->style_player_turn->fg[0].green = 0x0000;
 	global->style_player_turn->fg[0].blue  = 0x0000;
 
-	global->style_estate_title = gtk_style_copy (rcstyle);
-//	global->style_estate_title->font = gdk_font_load("-*-times-*-r-*-*-24-*-*-*-*-*-*-*");
-/*	if(! global->style_estate_title->font)
-		global->style_estate_title = 0;
-*/
 	gtk_style_unref (rcstyle);
 }
-
