@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,10 @@
 
 #include <gtk/gtk.h>
 
-#define DATAFILE_XMLROOTELEMENT "gtkatlantic"
+#define DATAFILE_XMLROOTELEMENT (xmlChar*)"gtkatlantic"
 
 
-gboolean parse_file_config(guchar *filename);
+gboolean parse_file_config(gchar *filename);
 gboolean xmlparse_file_interface();
 gboolean intro_load_pngs();
 void intro_free_pngs();
