@@ -39,9 +39,17 @@
 
 #include "parser.h"
 
+#ifdef WIN32
+#include <winsock2.h>
+#endif
 
 int main(int argc, char **argv)  {
 
+#ifdef WIN32
+	WSADATA wsaData;
+	if (WSAStartup(MAKEWORD(1, 1), &wsaData) != 0) exit(-1);
+#endif
+
 	global = g_malloc0( sizeof(_global) );
 	data = g_malloc0( sizeof(_data) );
 	config = g_malloc0( sizeof(_config) );
@@ -60,7 +68,7 @@ int main(int argc, char **argv)  {
 	init_prototype_gtk_style();
 
 	interface_create_mainwindow();
-	interface_create_menubar();  
+	interface_create_menubar();
 	interface_create_logo();
 
 	/* ---- add timeout */
