@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,38 +24,38 @@
 
 typedef struct {
 
-	guint16 width;
-	guint16 height;
-	guint32 rowbytes;
-	guint8 channels;
+	gint32 width;
+	gint32 height;
+	gint32 rowbytes;
+	gint32 channels;
 
-	guint32 bit_depth;
-	guint32 color_type;
+	gint32 bit_depth;
+	gint32 color_type;
 
-	guint32 size;
-	guint32 size_image;
-	guint32 size_alpha;
+	gint32 size;
+	gint32 size_image;
+	gint32 size_alpha;
 	gboolean have_alpha;
 	gboolean available_alpha;
-	guint32 nb_pixel;
+	gint32 nb_pixel;
 
-	guchar *image;
+	guint8 *image;
 	gboolean image_allocated;
 	gboolean image_need;
-	guchar *alpha;
+	guint8 *alpha;
 	gboolean alpha_allocated;
 	gboolean alpha_need;
 
-	guchar *part_image;
-	guchar *part_alpha;
+	guint8 *part_image;
+	guint8 *part_alpha;
 
 } _png_imagedata;
 
 
 gboolean readpng_init(FILE *infile, png_structp *png_struct, png_infop *png_info, _png_imagedata *png_imagedata);
 gboolean readpng_decode_image(png_structp *png_struct, png_infop *png_info, _png_imagedata *png_imagedata, gboolean get_alpha);
-guchar *readpng_get_image(_png_imagedata *png_imagedata);
-guchar *readpng_get_alpha(_png_imagedata *png_imagedata);
-guchar *readpng_get_image_zone(_png_imagedata *png_imagedata, guint16 x, guint16 y, guint16 width, guint16 height);
-guchar *readpng_get_alpha_zone(_png_imagedata *png_imagedata, guint16 x, guint16 y, guint16 width, guint16 height);
+guint8 *readpng_get_image(_png_imagedata *png_imagedata);
+guint8 *readpng_get_alpha(_png_imagedata *png_imagedata);
+guint8 *readpng_get_image_zone(_png_imagedata *png_imagedata, gint32 x, gint32 y, gint32 width, gint32 height);
+guint8 *readpng_get_alpha_zone(_png_imagedata *png_imagedata, gint32 x, gint32 y, gint32 width, gint32 height);
 void readpng_cleanup(png_structp *png_struct, png_infop *png_info, _png_imagedata *png_imagedata);
