@@ -365,7 +365,7 @@ void theme_build_selection_win()  {
 	gtk_container_add(GTK_CONTAINER(Alignment), Label);
 
 	/* preview */
-	PreviewFrame = gtk_frame_new("Preview");	
+	PreviewFrame = gtk_frame_new("Preview");
 	gtk_box_pack_start(GTK_BOX(VBoxInfo), PreviewFrame, TRUE, TRUE, 0);
 
 	Alignment = gtk_alignment_new(0.5, 0.5, 0.0, 0.0);
@@ -416,12 +416,12 @@ void theme_fill_selection_list()  {
 
 void theme_preview_free()  {
 
-	GtkWidget *Alignment;
+//	GtkWidget *Alignment;
 	GtkWidget *Preview;
 	gchar *buf = 0;
 
 	/* free all preview data */
-	Alignment = gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_container");
+//	Alignment = gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_container");
 	Preview = gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_data");
 
 	gtk_widget_destroy(Preview);
@@ -469,7 +469,7 @@ void theme_display(gint32 themeid)  {
 	Alignment = gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_container");
 	Preview = gtk_object_get_data(GTK_OBJECT(global->ThemeWin), "theme_preview_data");
 
-	theme_preview_free();	
+	theme_preview_free();
 
 	/* put new preview data */
 	if(! (buf = theme_preview_read(themeid, &width, &height)) )  {
