@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,11 +34,11 @@
 void     theme_build_database();
 gboolean theme_get_valid_slot(guint32 *themeslot);
 void     theme_del_entry(guint32 slot);
-void     theme_add_entry(guchar *path);
+void     theme_add_entry(gchar *path);
 void     theme_build_selection_win();
 void     theme_fill_selection_list();
 void     theme_preview_free();
 void     theme_display(gint32 themeid);
-guchar*  theme_preview_read(gint32 themeid, guint32 *width, guint32 *height);
+guint8*  theme_preview_read(gint32 themeid, guint32 *width, guint32 *height);
 void     theme_load(gint32 themeid);
 
