@@ -354,48 +354,45 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 			text = g_strdup_printf("%d", game->trade[tradeslot].tradeid);
 			gtk_object_set_data_full(GTK_OBJECT(Button), "tradeid", text, g_free);
 			gtk_widget_set_usize(Button, 60, 0);
+
 			gtk_signal_connect(GTK_OBJECT(Button), "clicked", (GtkSignalFunc)CallBack_trade_update_component, NULL);
 			gtk_container_add(GTK_CONTAINER(Alignment), Button);
 
 			/* valid estates */
-			Combo = gtk_combo_new();
-			gtk_editable_set_editable( GTK_EDITABLE(GTK_COMBO(Combo)->entry), FALSE);
-			gtk_object_set_data(GTK_OBJECT(Button), "name_estate", GTK_COMBO(Combo)->entry);
+			Combo = gtk_combo_box_entry_new_text();
+			gtk_editable_set_editable(GTK_EDITABLE(GTK_BIN(Combo)->child), FALSE);
+			gtk_object_set_data(GTK_OBJECT(Button), "name_estate", GTK_BIN(Combo)->child);
+
 			gtk_box_pack_start(GTK_BOX(box), Combo, TRUE, TRUE, 0);
-			list = NULL;
+
 			for(i = 0 ; i < data->number_estates ; i++)  {
 
 				if(game->estate[i].owner <= 0)  continue;
-				list = g_list_append(list, game->estate[i].name);
+				gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), game->estate[i].name);
 			}
-			if(list)  {
-				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
-				g_list_free(list);
-			}
-			gtk_combo_set_use_arrows_always(GTK_COMBO(Combo), TRUE);
+
+			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
 
 			/* target label */
 			Label = gtk_label_new("Target");
 			gtk_box_pack_start(GTK_BOX(box), Label, FALSE, FALSE, 0);
 
 			/* valid target players */
-			Combo = gtk_combo_new();
+			Combo = gtk_combo_box_entry_new_text();
+			gtk_editable_set_editable(GTK_EDITABLE(GTK_BIN(Combo)->child), FALSE);
+			gtk_object_set_data(GTK_OBJECT(Button), "name_target_player", GTK_BIN(Combo)->child);
+
 			gtk_widget_set_usize(Combo, 120, 0);
-			gtk_editable_set_editable( GTK_EDITABLE(GTK_COMBO(Combo)->entry), FALSE);
-			gtk_object_set_data(GTK_OBJECT(Button), "name_target_player", GTK_COMBO(Combo)->entry);
 			gtk_box_pack_start(GTK_BOX(box), Combo, FALSE, FALSE, 0);
-			list = NULL;
+
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
 				if(!global->player[i].playerid)  continue;
 				if(global->player[i].game != game->gameid)  continue;
-				list = g_list_append(list, global->player[i].name);
+				gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), global->player[i].name);
 			}
-			if(list)  {
-				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
-				g_list_free(list);
-			}
-			gtk_combo_set_use_arrows_always(GTK_COMBO(Combo), TRUE);
+
+			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
 
 			break;
 
@@ -424,44 +421,41 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 			gtk_box_pack_start(GTK_BOX(box), Label, FALSE, FALSE, 0);
 
 			/* valid from players */
-			Combo = gtk_combo_new();
-			gtk_editable_set_editable( GTK_EDITABLE(GTK_COMBO(Combo)->entry), FALSE);
-			gtk_object_set_data(GTK_OBJECT(Button), "name_from_player", GTK_COMBO(Combo)->entry);
+			Combo = gtk_combo_box_entry_new_text();
+			gtk_editable_set_editable(GTK_EDITABLE(GTK_BIN(Combo)->child), FALSE);
+			gtk_object_set_data(GTK_OBJECT(Button), "name_from_player", GTK_BIN(Combo)->child);
+
 			gtk_box_pack_start(GTK_BOX(box), Combo, TRUE, TRUE, 0);
-			list = NULL;
+
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
 				if(!global->player[i].playerid)  continue;
 				if(global->player[i].game != game->gameid)  continue;
-				list = g_list_append(list, global->player[i].name);
+				gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), global->player[i].name);
+
 			}
-			if(list)  {
-				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
-				g_list_free(list);
-			}
-			gtk_combo_set_use_arrows_always(GTK_COMBO(Combo), TRUE);
+
+			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
 
 			/* to label */
 			Label = gtk_label_new("To");
 			gtk_box_pack_start(GTK_BOX(box), Label, FALSE, FALSE, 0);
 
 			/* valid to players */
-			Combo = gtk_combo_new();
-			gtk_editable_set_editable( GTK_EDITABLE(GTK_COMBO(Combo)->entry), FALSE);
-			gtk_object_set_data(GTK_OBJECT(Button), "name_to_player", GTK_COMBO(Combo)->entry);
+			Combo = gtk_combo_box_entry_new_text();
+			gtk_editable_set_editable(GTK_EDITABLE(GTK_BIN(Combo)->child), FALSE);
+			gtk_object_set_data(GTK_OBJECT(Button), "name_to_player", GTK_BIN(Combo)->child);
+
 			gtk_box_pack_start(GTK_BOX(box), Combo, TRUE, TRUE, 0);
-			list = NULL;
+
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
 				if(!global->player[i].playerid)  continue;
 				if(global->player[i].game != game->gameid)  continue;
-				list = g_list_append(list, global->player[i].name);
+				gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), global->player[i].name);
 			}
-			if(list)  {
-				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
-				g_list_free(list);
-			}
-			gtk_combo_set_use_arrows_always(GTK_COMBO(Combo), TRUE);
+
+			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
 
 			break;
 
@@ -480,9 +474,10 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 			gtk_container_add(GTK_CONTAINER(Alignment), Button);
 
 			/* valid cards */
-			Combo = gtk_combo_new();
-			gtk_editable_set_editable( GTK_EDITABLE(GTK_COMBO(Combo)->entry), FALSE);
-			gtk_object_set_data(GTK_OBJECT(Button), "name_card", GTK_COMBO(Combo)->entry);
+			Combo = gtk_combo_box_entry_new_text();
+			gtk_editable_set_editable(GTK_EDITABLE(GTK_BIN(Combo)->child), FALSE);
+			gtk_object_set_data(GTK_OBJECT(Button), "name_card", GTK_BIN(Combo)->child);
+
 			gtk_box_pack_start(GTK_BOX(box), Combo, TRUE, TRUE, 0);
 			list = NULL;
 			for(i = 0 ; i < MAX_CARDS ; i++)  {
@@ -490,9 +485,13 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 				if(!game->card[i].owner)  continue;
 				text = g_strdup_printf("%d", game->card[i].cardid);
 				list = g_list_append(list, text);
+				gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), text);
+
 			}
+
 			if(list)  {
-				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
+
+				gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
 
 				for(i = 0 ;  ; i++)  {
 
@@ -503,30 +502,28 @@ void trade_rebuild_subcomponent(gint32 tradeslot)  {
 				}
 				g_list_free(list);
 			}
-			gtk_combo_set_use_arrows_always(GTK_COMBO(Combo), TRUE);
 
 			/* target label */
 			Label = gtk_label_new("Target");
 			gtk_box_pack_start(GTK_BOX(box), Label, FALSE, FALSE, 0);
 
 			/* valid target players */
-			Combo = gtk_combo_new();
+			Combo = gtk_combo_box_entry_new_text();
+			gtk_editable_set_editable(GTK_EDITABLE(GTK_BIN(Combo)->child), FALSE);
+			gtk_object_set_data(GTK_OBJECT(Button), "name_target_player", GTK_BIN(Combo)->child);
 			gtk_widget_set_usize(Combo, 120, 0);
-			gtk_editable_set_editable( GTK_EDITABLE(GTK_COMBO(Combo)->entry), FALSE);
-			gtk_object_set_data(GTK_OBJECT(Button), "name_target_player", GTK_COMBO(Combo)->entry);
+
 			gtk_box_pack_start(GTK_BOX(box), Combo, FALSE, FALSE, 0);
-			list = NULL;
+
 			for(i = 0 ; i < MAX_PLAYERS ; i++)  {
 
 				if(!global->player[i].playerid)  continue;
 				if(global->player[i].game != game->gameid)  continue;
-				list = g_list_append(list, global->player[i].name);
+				gtk_combo_box_append_text(GTK_COMBO_BOX(Combo), global->player[i].name);
 			}
-			if(list)  {
-				gtk_combo_set_popdown_strings(GTK_COMBO(Combo), list);
-				g_list_free(list);
-			}
-			gtk_combo_set_use_arrows_always(GTK_COMBO(Combo), TRUE);
+
+			gtk_combo_box_set_active(GTK_COMBO_BOX(Combo), 0);
+
 			break;
 	}
 
@@ -552,7 +549,7 @@ void trade_update_player(gint32 tradeid, gint32 playerid, gboolean accept)  {
 void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer)  {
 
 	gchar *txt[10], **text[2];
-	gint32 row, tradeslot, test, i;
+	gint32 tradeslot, test, i;
 	GtkWidget *ProposalCList;
 	gchar *cardname;
 
@@ -595,7 +592,7 @@ void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer)  {
 	txt[7] = g_strdup_printf("%d", targetplayer);
 	txt[8] = g_strdup_printf("%d", cardid);
 	txt[9] = g_strdup_printf("%d", tradeslot);
-	row = gtk_clist_append(GTK_CLIST(ProposalCList), txt);
+	gtk_clist_append(GTK_CLIST(ProposalCList), txt);
 	g_free(txt[0]);
 	g_free(txt[2]);
 	g_free(txt[5]);
@@ -611,7 +608,7 @@ void trade_update_card(gint32 tradeid, gint32 cardid, gint32 targetplayer)  {
 void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer)  {
 
 	gchar *txt[10], **text[2];
-	gint32 row, tradeslot, test, i;
+	gint32 tradeslot, test, i;
 	GtkWidget *ProposalCList;
 	gchar *estatename;
 
@@ -650,7 +647,7 @@ void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer)
 	txt[7] = g_strdup_printf("%d", targetplayer);
 	txt[8] = g_strdup_printf("%d", estateid);
 	txt[9] = g_strdup_printf("%d", tradeslot);
-	row = gtk_clist_append(GTK_CLIST(ProposalCList), txt);
+	gtk_clist_append(GTK_CLIST(ProposalCList), txt);
 	g_free(txt[0]);
 	g_free(txt[2]);
 	g_free(txt[5]);
@@ -664,7 +661,7 @@ void trade_update_estate(gint32 tradeid, gint32 estateid, gint32 targetplayer)
 void trade_update_money(gint32 tradeid, gint32 playerfrom, gint32 playerto, gint32 money)  {
 
 	gchar *txt[10], **text[2];
-	gint32 row, tradeslot, test, i;
+	gint32 tradeslot, test, i;
 	GtkWidget *ProposalCList;
 	gchar *from, *to, *moneystr;
 
@@ -710,7 +707,7 @@ void trade_update_money(gint32 tradeid, gint32 playerfrom, gint32 playerto, gint
 	txt[7] = g_strdup_printf("%d", playerto);
 	txt[8] = g_strdup_printf("%d", money);
 	txt[9] = g_strdup_printf("%d", tradeslot);
-	row = gtk_clist_append(GTK_CLIST(ProposalCList), txt);
+	gtk_clist_append(GTK_CLIST(ProposalCList), txt);
 	g_free(txt[0]);
 	g_free(txt[2]);
 	g_free(txt[5]);
