@@ -123,6 +123,7 @@ void xmlparse_getgamelist_plugger(guint32 connectid, gchar *buffer)  {
 	for( cur = cur->xmlChildrenNode ; cur != NULL ; cur = cur -> next)  {
 
 		if(! xmlStrcmp(cur->name, (xmlChar*)"server") )  xmlparse_server(connectid, doc, cur);
+		// TODO: use gameupdate instead
 		if(! xmlStrcmp(cur->name, (xmlChar*)"updategamelist") )  xmlparse_updategamelist(connectid, doc, cur);
 	}
 
@@ -178,6 +179,7 @@ void xmlparse_game_plugger(guint32 connectid, gchar *buffer)  {
 void xmlparse_server(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlChar *tmp;
+	(void)doc;
 
 	tmp = xmlGetProp(cur, (xmlChar*)"version");
 	if(tmp)  connection[connectid]->server_version = (gchar*)tmp;
@@ -189,6 +191,8 @@ void xmlparse_server(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 void xmlparse_client(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlChar *tmp;
+	(void)connectid;
+	(void)doc;
 
 	tmp = xmlGetProp(cur, (xmlChar*)"playerid");
 	if( tmp )  {
@@ -212,7 +216,9 @@ void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur) {
 	struct timeval tv;
 	guint32 i;
 	gint32 gameid;
-	
+	(void)connectid;
+	(void)doc;
+
 	tmp = xmlGetProp(cur, (xmlChar*)"gameid");
 	if(tmp)  {
 		gameid = atoi((gchar*)tmp);
@@ -289,10 +295,12 @@ void xmlparse_gameupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur) {
 void xmlparse_message(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	gchar *type, *text, *author, *value;
+	(void)connectid;
+	(void)doc;
 
 	type = (gchar*)xmlGetProp(cur, (xmlChar*)"type");
 
-	if(! g_strncasecmp(type, "chat", 4) )  {
+	if(! g_ascii_strncasecmp(type, "chat", 4) )  {
 
 		author = (gchar*)xmlGetProp(cur, (xmlChar*)"author");
 		value = (gchar*)xmlGetProp(cur, (xmlChar*)"value");
@@ -314,10 +322,11 @@ void xmlparse_message(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	}
 	else {
 
-		g_strup( type );
+		gchar *typeup = g_utf8_strup( type, -1 );
 		value = (gchar*)xmlGetProp(cur, (xmlChar*)"value");
-		text = g_strdup_printf("%s: %s", type, value);
+		text = g_strdup_printf("%s: %s", typeup, value);
 		text_insert_message(text, strlen(text));
+		g_free(typeup);
 		g_free(text);
 		g_free(value);
 	}
@@ -332,9 +341,11 @@ void xmlparse_estateupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	guint32 color[3], i;
 	xmlChar *tmp;
-	guint32 id, frame, pic, star;
-	gint32 t, u;
+	guint32 frame, pic, star;
+	gint32 id, t, u;
 	gboolean owner_mortgage_changed = FALSE;
+	(void)connectid;
+	(void)doc;
 
 	tmp = xmlGetProp(cur, (xmlChar*)"estateid");
 	if(!tmp)  return;
@@ -596,7 +607,8 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	xmlChar *tmp;
 	GtkWidget *Combo, *StartButton, *Button;
 	GList *list;
-
+	(void)connectid;
+	(void)doc;
 
 	tmp = xmlGetProp(cur, (xmlChar*)"playerid");
 	if(!tmp) return;
@@ -622,7 +634,7 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	tmp = xmlGetProp(cur, (xmlChar*)"game");
 	if(tmp)  {
-	
+
 		global->player[id].game = atoi((gchar*)tmp);
 		g_free(tmp);
 	}
@@ -641,9 +653,9 @@ void xmlparse_playerupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 		global->player[id].master = atoi((gchar*)tmp);
 		g_free(tmp);
 
-		if(global->player[id].master  &&  game->my_playerid == playerid)
+		if(global->player[id].master  &&  game->my_playerid == (guint32)playerid)
 			game->i_am_the_master = TRUE;
-		if(!global->player[id].master  &&  game->my_playerid == playerid)
+		if(!global->player[id].master  &&  game->my_playerid == (guint32)playerid)
 			game->i_am_the_master = FALSE;
 
 		/* set sensitive mode of start button */
@@ -823,6 +835,9 @@ void xmlparse_auctionupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlChar *tmp;
 
+	(void)connectid;
+	(void)doc;
+
 	tmp = xmlGetProp(cur, (xmlChar*)"auctionid");
 	if(!tmp) return;
 	auctionid = atoi((gchar*)tmp);
@@ -952,6 +967,8 @@ void xmlparse_display(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	xmlChar *tmp;
 	gchar *caption, *command;
 	gboolean enable;
+	(void)connectid;
+	(void)doc;
 
 	if( game->status != GAME_STATUS_RUN)  return;
 
@@ -1017,6 +1034,8 @@ void xmlparse_configupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	gchar *text, *title, *command;
 	guint32 signalid;
 	xmlChar *tmp;
+	(void)connectid;
+	(void)doc;
 
 	for( cur2 = cur->xmlChildrenNode ; cur2 != NULL ; cur2 = cur2 -> next)  {
 
@@ -1106,9 +1125,11 @@ void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlNodePtr cur2;
 	xmlChar *tmp;
-	guint32 tradeid = 0, playerid = 0, actor = 0, cardid = 0, estateid = 0;
+	guint32 tradeid = 0, playerid = 0, cardid = 0, estateid = 0;
 	guint32 targetplayer = 0, playerfrom = 0, playerto = 0, money = 0;
 	gboolean accept = FALSE;
+	(void)connectid;
+	(void)doc;
 
 	if( game->status != GAME_STATUS_RUN)  return;
 
@@ -1119,11 +1140,11 @@ void xmlparse_tradeupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 	}
 	else  return;
 
-	tmp = xmlGetProp(cur, (xmlChar*)"actor");
-	if(tmp)   {
-		actor = atoi((gchar*)tmp);
-		g_free(tmp);
-	}
+//	tmp = xmlGetProp(cur, (xmlChar*)"actor");
+//	if(tmp)   {
+//		actor = atoi((gchar*)tmp);
+//		g_free(tmp);
+//	}
 
 	tmp = xmlGetProp(cur, (xmlChar*)"type");
 	if(tmp)  {
@@ -1244,6 +1265,8 @@ void xmlparse_cardupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlChar *tmp;
 	gint32 cardid = 0, owner = 0, i, cardslot = 0;
+	(void)connectid;
+	(void)doc;
 
 	if( game->status != GAME_STATUS_RUN)  return;
 
@@ -1296,6 +1319,8 @@ void xmlparse_estategroupupdate(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur
 
 	xmlChar *tmp;
 	gint32 groupid = -1;
+	(void)connectid;
+	(void)doc;
 
 	tmp = xmlGetProp(cur, (xmlChar*)"groupid");
 	if(tmp)  {
@@ -1317,6 +1342,8 @@ void xmlparse_deleteplayer(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)  {
 
 	xmlChar *tmp;
 	gint32 playerid = -1, id;
+	(void)connectid;
+	(void)doc;
 
 	tmp = xmlGetProp(cur, (xmlChar*)"playerid");
 	if(tmp)  {
@@ -1343,6 +1370,7 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 	gint32 id, test, i;
 	xmlNodePtr cur2;
 	xmlChar *type;
+	(void)doc;
 
 	if(global->phase != PHASE_GETGAMES)  {
 
@@ -1386,7 +1414,7 @@ void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur)
 			if(! xmlStrcmp(cur2->name, (xmlChar*)"game") )  {
 
 				xmlChar *tmp;
-				
+
 				tmp = xmlGetProp(cur2, (xmlChar*)"canbejoined");
 				if(tmp  &&  atoi((gchar*)tmp) == 0 )  {
 
