@@ -2,7 +2,7 @@
  *     gtkatlantic - the gtk+ monopd client, enjoy network monopoly games
  *
  *
- *  Copyright (C) 2002-2004 Rochet Sylvain
+ *  Copyright (C) 2002-2010 Rochet Sylvain
  *
  *  gtkatlantic is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,11 +22,11 @@
 #include <gtk/gtk.h>
 #include <libxml/parser.h>
 
-#define SERVER_XMLROOTELEMENT "monopd"
-#define METASERVER_XMLROOTELEMENT "meta_atlantic"
+#define SERVER_XMLROOTELEMENT (xmlChar*)"monopd"
+#define METASERVER_XMLROOTELEMENT (xmlChar*)"meta_atlantic"
 
-void xmlparse_getgamelist_plugger(guint32 connectid, guchar *buffer);
-void xmlparse_game_plugger(guint32 connectid, guchar *buffer);
+void xmlparse_getgamelist_plugger(guint32 connectid, gchar *buffer);
+void xmlparse_game_plugger(guint32 connectid, gchar *buffer);
 
 void xmlparse_server(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
 void xmlparse_client(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
@@ -44,6 +44,6 @@ void xmlparse_deleteplayer(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
 
 void xmlparse_updategamelist(guint32 connectid, xmlDocPtr doc, xmlNodePtr cur);
 
-void xmlparse_metaserver(guint32 connectid, guchar *buffer);
+void xmlparse_metaserver(guint32 connectid, gchar *buffer);
 
 
